==> insighttoolkit4_4.5.0.orig.tar.xz: InsightToolkit-4.5.0/Modules/Compatibility/Deprecated/include/itkDicomImageIO.h <==
/*=========================================================================
 *
 *  Copyright Insight Software Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/
#ifndef __itkDicomImageIO_h
#define __itkDicomImageIO_h
#if !defined( ITK_LEGACY_REMOVE )


#include "itkGDCMImageIO.h"

namespace itk
{
/** \class DicomImageIO
 *
 *  \brief Read DicomImage file format.
 *  \warning NOTE: This reader has been replaced with GDCMImageIO
 *
 *  \deprecated
 * \ingroup ITKDeprecated
 * \ingroup IOFilters
 */
class DicomImageIO:public GDCMImageIO
{
public:
  /** Standard class typedefs. */
  typedef DicomImageIO         Self;
  typedef GDCMImageIO          Superclass;
  typedef SmartPointer< Self > Pointer;

  /** Method for creation through the object factory. */
  itkNewMacro(Self);

  /** Run-time type information (and related methods). */
  itkTypeMacro(DicomImageIO, Superclass);

protected:
  DicomImageIO()
  {
    itkWarningMacro (
      <<
      "DicomImageIO is now implemented as a subclass of GDCMImageIO. Please replace your DicomImageIO references with GDCMImageIO.");
  }

private:
  DicomImageIO(const Self &);   //purposely not implemented
  void operator=(const Self &); //purposely not implemented
};
} // end namespace itk

#endif //#if !defined( ITK_LEGACY_REMOVE )
#endif // __itkDicomImageIO_h

==> insighttoolkit4_4.10.1-dfsg1.orig.tar.xz: InsightToolkit-4.10.1/Modules/Compatibility/Deprecated/include/itkDicomImageIO.h <==
/*=========================================================================
 *
 *  Copyright Insight Software Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/
#ifndef itkDicomImageIO_h
#define itkDicomImageIO_h
#if !defined( ITK_LEGACY_REMOVE )


#include "itkGDCMImageIO.h"

namespace itk
{
/** \class DicomImageIO
 *
 *  \brief Read DicomImage file format.
 *  \warning NOTE: This reader has been replaced with GDCMImageIO
 *
 *  \deprecated
 * \ingroup ITKDeprecated
 * \ingroup IOFilters
 */
class DicomImageIO:public GDCMImageIO
{
public:
  /** Standard class typedefs. */
  typedef DicomImageIO         Self;
  typedef GDCMImageIO          Superclass;
  typedef SmartPointer< Self > Pointer;

  /** Method for creation through the object factory. */
  itkNewMacro(Self);

  /** Run-time type information (and related methods). */
  itkTypeMacro(DicomImageIO, Superclass);

protected:
  DicomImageIO()
  {
    itkWarningMacro (
      <<
      "DicomImageIO is now implemented as a subclass of GDCMImageIO. Please replace your DicomImageIO references with GDCMImageIO.");
  }

private:
  DicomImageIO(const Self &) ITK_DELETE_FUNCTION;
  void operator=(const Self &) ITK_DELETE_FUNCTION;
};
} // end namespace itk

#endif //#if !defined( ITK_LEGACY_REMOVE )
#endif // itkDicomImageIO_h
